# streamlit-searchbar

Search bar component

## Installation instructions 

```sh
pip install streamlit-searchbar
```

## Usage instructions

```python
import streamlit as st

from streamlit_searchbar import streamlit_searchbar

value = streamlit_searchbar()

st.write(value)
